
/** 
 * Renders an icon that represents a panorama's viewing direction and field-of-view.
 * 
 * @param graphics the graphics context to render to.
 * @param position the photo position location on the graphics context.
 * @param colorDark the color used for outlines.
 * @param color the color using for fillings.
 * @param pan the heading or pan angle of the viewer (clockwise, 0 means north).
 * @param fov the field-of-view angle of the viewer.
 * Note : graphics is never cleared by this function.
 */
function drawFOVSymbol(graphics:Graphics,position:Point,colorDark:uint,color:uint,pan:Number,fov:Number):void {

	// move from pan angle (0° is north) to geometric angle (0° is east).
	pan = pan-90;

	var pointsPerArc:int = 12;
	var i:int;

	var RAD_TO_DEG:Number = 180.0/Math.PI;
	var DEG_TO_RAD:Number = Math.PI/180.0;		

	var start:Number = pan-(fov/2);
	var stop:Number = pan+(fov/2);
	var innerArcDistance:Number = 8;
	var outerArcDistance:Number = 40;

	graphics.lineStyle(1,colorDark,2.0);
	graphics.beginFill(color,0.9);

	//
	// Inner Arc
	//

	for (i=0;i<pointsPerArc;i++)
	{
		var a:Number = start+(i*((stop-start)/pointsPerArc));
		var x:Number = position.x+(Math.cos(DEG_TO_RAD*a)*innerArcDistance);
		var y:Number = position.y+(Math.sin(DEG_TO_RAD*a)*innerArcDistance);
		if (i==0) graphics.moveTo(x,y);
		else graphics.lineTo(x,y);
	}

	//
	// Outer Arc
	//

	for (i=pointsPerArc;i>0;i--)
	{
		var a:Number = start+(i*((stop-start)/pointsPerArc));
		var x:Number = position.x+(Math.cos(DEG_TO_RAD*a)*outerArcDistance);
		var y:Number = position.y+(Math.sin(DEG_TO_RAD*a)*outerArcDistance);
		graphics.lineTo(x,y);
	}

	graphics.endFill();

	//
	// Centerline
	//

	var x = position.x+(Math.cos(DEG_TO_RAD*pan)*(outerArcDistance*0.80));
	var y = position.y+(Math.sin(DEG_TO_RAD*pan)*(outerArcDistance*0.80));
	var x2 = position.x+(Math.cos(DEG_TO_RAD*pan)*(outerArcDistance*1.05));
	var y2 = position.y+(Math.sin(DEG_TO_RAD*pan)*(outerArcDistance*1.05));
	graphics.moveTo(x,y);
	graphics.lineTo(x2,y2);

	//
	// ViewerID
	//
	//var x = position.x+(Math.cos(DEG_TO_RAD*pan)*(outerArcDistance*0.50));
	//var y = position.y+(Math.sin(DEG_TO_RAD*pan)*(outerArcDistance*0.50));
}
